jQuery(document).ready(function ($) {
  // Initialize SSSI object with defaults if not set
  if (typeof SSSI === "undefined" || !SSSI.icons) {
    console.error("SSSI settings not properly initialized");
    SSSI = {
      icons: {},
      defaults: {
        networks: ["facebook", "x", "linkedin"],
        icon_style: "brand",
        icon_shape: "rounded",
        alignment: "left",
        text_position: "above",
        share_text: "Share with friends:",
        button_size: "40",
        icon_spacing: "8",
        icon_size: 24,
      },
    };
  }

  // Debug output
  if (SSSI.debug) {
    console.log("SSSI initialized with:", SSSI);
  }

  // Tab switching functionality
  $(".sssi-tab").on("click", function (e) {
    e.preventDefault();
    const tabId = $(this).data("tab");

    // Update active states
    $(".sssi-tab").removeClass("active");
    $(this).addClass("active");

    // Show selected content with fade effect
    $(".sssi-tab-content")
      .fadeOut(200)
      .promise()
      .done(function () {
        $("#" + tabId).fadeIn(200);
      });
  });

  // Network button click handler
  $(".sssi-network-button").on("click", function () {
    const $button = $(this);
    const $checkbox = $button.find('input[type="checkbox"]');

    // Toggle checked state with animation
    $button.toggleClass("checked");
    $checkbox.prop("checked", $button.hasClass("checked"));

    // Update preview with animation
    updatePreview(true);
  });

  // Show/hide custom colors section
  $('input[name="sssi_options[icon_style]"]').on("change", function () {
    const showCustomColors = $(this).val() === "custom";
    const $customColors = $(".sssi-custom-colors");

    if (showCustomColors) {
      $customColors.addClass("active").slideDown(200);
    } else {
      $customColors.removeClass("active").slideUp(200);
    }

    // Force layout recalculation
    setTimeout(() => {
      if (showCustomColors) {
        $customColors.css("display", "flex");
      }
    }, 210);

    updatePreview(true);
  });

  // Show/hide shortcode display
  $('input[name="sssi_options[position]"]').on("change", function () {
    const showShortcode = $(this).val() === "shortcode";
    if (showShortcode) {
      $(".sssi-shortcode-display").slideDown(200);
    } else {
      $(".sssi-shortcode-display").slideUp(200);
    }
  });

  // Size controls
  $('.sssi-size-control input[type="range"]').on("input", function () {
    const $control = $(this).closest(".sssi-size-control");
    $control.find(".size-value").text($(this).val() + "px");
    updatePreview(true);
  });

  // Color picker changes
  $('.sssi-color-field input[type="color"]').on(
    "input",
    debounce(function () {
      updatePreview(true);
    }, 100)
  );

  // Real-time preview updates for text input
  $('input[name="sssi_options[share_text]"]').on(
    "input",
    debounce(function () {
      updatePreview(true);
    }, 300)
  );

  // Immediate preview updates for radio buttons
  $('input[type="radio"][name^="sssi_options"]').on("change", function () {
    updatePreview(true);
  });

  // Add these to your existing event listeners
  $('input[name="sssi_options[text_style]"]').on("change", function () {
    updatePreview(true);
  });

  $('input[name="sssi_options[text_weight]"]').on("change", function () {
    updatePreview(true);
  });

  function updatePreview(animate = false) {
    // Only log if debug mode is enabled and it's a significant change
    const shouldLog = SSSI.debug && animate;

    const previewContent = $(".sssi-preview-content");

    // Get current settings
    const settings = {
      shareText:
        $('input[name="sssi_options[share_text]"]').val() ||
        SSSI.defaults.share_text,
      iconStyle:
        $('input[name="sssi_options[icon_style]"]:checked').val() ||
        SSSI.defaults.icon_style,
      iconShape:
        $('input[name="sssi_options[icon_shape]"]:checked').val() ||
        SSSI.defaults.icon_shape,
      alignment:
        $('input[name="sssi_options[alignment]"]:checked').val() ||
        SSSI.defaults.alignment,
      textPosition:
        $('input[name="sssi_options[text_position]"]:checked').val() ||
        SSSI.defaults.text_position,
      iconSize:
        $('input[name="sssi_options[icon_size]"]').val() ||
        SSSI.defaults.icon_size,
      iconSpacing:
        $('input[name="sssi_options[icon_spacing]"]').val() ||
        SSSI.defaults.icon_spacing,
      textStyle:
        $('input[name="sssi_options[text_style]"]:checked').val() || "normal",
      textWeight:
        $('input[name="sssi_options[text_weight]"]:checked').val() || "normal",
      textSize: $('input[name="sssi_options[text_size]"]').val() || "16",
      networks: [],
      customColors: {
        bg: $('input[name="sssi_options[custom_bg_color]"]').val(),
        icon: $('input[name="sssi_options[custom_icon_color]"]').val(),
        border: $('input[name="sssi_options[custom_border_color]"]').val(),
      },
    };

    if (shouldLog) {
      console.log("Preview updated with settings:", settings);
    }

    // Get selected networks
    $(".sssi-network-button.checked").each(function () {
      settings.networks.push($(this).data("network"));
    });

    // Calculate button padding and size based on icon size
    const iconSize = Number(settings.iconSize);
    const buttonPadding = Math.round(iconSize * 0.3);
    const buttonSize = iconSize + buttonPadding * 2;

    // Create container with all necessary CSS variables
    const container = $("<div>", {
      class: `sssi-container sssi-style-${settings.iconStyle} sssi-shape-${settings.iconShape}`,
      style: `
        --sssi-icon-size: ${settings.iconSize}px;
        --sssi-spacing: ${settings.iconSpacing}px;
        --sssi-button-padding: ${buttonPadding}px;
        --sssi-button-size: ${buttonSize}px;
        --sssi-text-size: ${settings.textSize}px;
      `,
    });

    // Add custom colors if enabled
    if (settings.iconStyle === "custom") {
      container.css({
        "--sssi-custom-bg": settings.customColors.bg,
        "--sssi-custom-icon": settings.customColors.icon,
        "--sssi-custom-border": settings.customColors.border,
      });
    }

    const content = $("<div>", {
      class: "sssi-content",
      "data-text-position": settings.textPosition,
      "data-alignment": settings.alignment,
      "data-text-style": settings.textStyle,
      "data-text-weight": settings.textWeight,
      style: `text-align: ${settings.alignment}`,
    });

    if (settings.shareText) {
      const title = $("<div>", {
        class: "sssi-title",
        text: settings.shareText,
        css: {
          "font-size": `${settings.textSize}px`,
          "font-weight":
            settings.textWeight === "normal"
              ? "400"
              : settings.textWeight === "medium"
              ? "500"
              : settings.textWeight === "semibold"
              ? "600"
              : "700",
          "text-transform":
            settings.textStyle === "uppercase" ? "uppercase" : "none",
          "text-decoration":
            settings.textStyle === "underline" ? "underline" : "none",
          "font-style": settings.textStyle === "italic" ? "italic" : "normal",
          "text-align": settings.alignment,
        },
      });
      content.append(title);
    }

    const buttons = $("<div>", {
      class: "sssi-buttons",
      css: {
        "justify-content":
          settings.alignment === "left"
            ? "flex-start"
            : settings.alignment === "center"
            ? "center"
            : "flex-end",
      },
    });

    // Add buttons
    settings.networks.forEach((network) => {
      if (SSSI.icons && SSSI.icons[network]) {
        const button = $("<a>", {
          href: "#",
          class: `sssi-button sssi-${network}`,
          html: `<span class="sssi-icon">${SSSI.icons[network]}</span>`,
        });
        buttons.append(button);
      }
    });

    content.append(buttons);
    container.append(content);

    // Update preview with animation if requested
    if (animate) {
      previewContent.fadeOut(200, function () {
        $(this).html(container).fadeIn(200);
      });
    } else {
      previewContent.html(container);
    }

    // Debug output
    if (SSSI.debug) {
      console.log("Preview updated with settings:", {
        ...settings,
        calculatedSizes: {
          buttonPadding,
          buttonSize,
        },
      });
    }
  }

  // Debounce function to limit update frequency
  function debounce(func, wait) {
    let timeout;
    return function executedFunction(...args) {
      const later = () => {
        clearTimeout(timeout);
        func(...args);
      };
      clearTimeout(timeout);
      timeout = setTimeout(later, wait);
    };
  }

  // Initialize preview
  updatePreview();

  // Show initial tab
  $(".sssi-tab-content").not(":first").hide();

  // Initialize custom colors visibility
  if ($('input[name="sssi_options[icon_style]"]:checked').val() === "custom") {
    $(".sssi-custom-colors").show();
  }

  // Initialize shortcode display visibility
  if ($('input[name="sssi_options[position]"]:checked').val() === "shortcode") {
    $(".sssi-shortcode-display").show();
  }

  // Save settings
  $("#sssi-settings-form").on("submit", function (e) {
    e.preventDefault();

    // Get selected networks
    const selectedNetworks = [];
    $('.sssi-network-button input[type="checkbox"]:checked').each(function () {
      selectedNetworks.push($(this).val());
    });

    // Create form data object
    const formData = new FormData(this);

    // Ensure networks are included
    if (selectedNetworks.length > 0) {
      formData.delete("sssi_options[networks][]"); // Remove existing network entries
      selectedNetworks.forEach((network) => {
        formData.append("sssi_options[networks][]", network);
      });
    }

    // Convert FormData to URL-encoded string
    const serializedData = new URLSearchParams(formData).toString();

    $.ajax({
      url: ajaxurl,
      type: "POST",
      data: {
        action: "save_sssi_settings",
        nonce: $("#sssi_settings_nonce").val(),
        form_data: serializedData,
      },
      success: function (response) {
        if (response.success) {
          showToast(response.data.message, "success");
          // Update preview with new options
          updatePreview(true);
        } else {
          showToast(response.data.message || "Error saving settings", "error");
        }
      },
      error: function () {
        showToast("Error saving settings", "error");
      },
    });
  });

  // Add active state handling for radio buttons
  $(".sssi-radio-label").on("click", function () {
    $(this)
      .closest(".sssi-radio-group")
      .find(".sssi-radio-label")
      .removeClass("active");
    $(this).addClass("active");
  });

  // Initialize active states
  $('.sssi-radio-label input[type="radio"]:checked')
    .parent()
    .addClass("active");

  // Add toast notification function
  function showToast(message, type = "success") {
    // Remove existing toast if any
    $(".sssi-toast").remove();

    // Create toast
    const toast = $("<div>", {
      class: "sssi-toast",
      html: `
            <span class="dashicons dashicons-${
              type === "success" ? "yes" : "warning"
            }"></span>
            <span>${message}</span>
        `,
    });

    // Add to body
    $("body").append(toast);

    // Show toast
    setTimeout(() => toast.addClass("show"), 100);

    // Hide and remove after 3 seconds
    setTimeout(() => {
      toast.removeClass("show");
      setTimeout(() => toast.remove(), 300);
    }, 3000);
  }

  // Initialize color pickers
  $('.sssi-color-field input[type="color"]').each(function () {
    $(this).css("opacity", 1); // Ensure color pickers are visible
  });

  // Replace the clipboard code with this
  function initializeClipboard() {
    $(".sssi-copy-button").on("click", function () {
      const text = $(this).data("clipboard-text");
      navigator.clipboard
        .writeText(text)
        .then(() => {
          // Visual feedback
          $(this).addClass("copied");
          const originalText = $(this).html();
          $(this).html('<span class="dashicons dashicons-yes"></span>Copied!');

          // Reset after 2 seconds
          setTimeout(() => {
            $(this).removeClass("copied").html(originalText);
          }, 2000);
        })
        .catch((err) => {
          console.error("Failed to copy text: ", err);
        });
    });
  }

  // Add this to your existing jQuery ready function
  $(document).ready(function () {
    // ... existing code ...

    initializeClipboard();
  });
});
