<?php
/**
 * Asset management class
 *
 * @package SSSI
 */

if (!defined('ABSPATH')) {
    exit;
}

class SSSI_Assets {
    /**
     * Register and enqueue assets
     */
    public static function register_assets() {
        // Frontend styles
        wp_register_style(
            'sssi-shared',
            SSSI_PLUGIN_URL . 'assets/css/sssi-shared.css',
            array(),
            SSSI_VERSION
        );

        wp_register_style(
            'sssi-frontend',
            SSSI_PLUGIN_URL . 'assets/css/sssi-frontend.css',
            array('sssi-shared'),
            SSSI_VERSION
        );

        // Admin styles
        wp_register_style(
            'sssi-admin',
            SSSI_PLUGIN_URL . 'assets/css/sssi-admin.css',
            array('sssi-shared'),
            SSSI_VERSION
        );

        // Admin scripts
        wp_register_script(
            'sssi-admin',
            SSSI_PLUGIN_URL . 'assets/js/sssi-admin.js',
            array('jquery'),
            SSSI_VERSION,
            true
        );
    }

    /**
     * Enqueue frontend assets
     */
    public static function enqueue_frontend_assets() {
        if (!is_singular() && !has_shortcode(get_the_content(), 'sssi')) {
            return;
        }

        wp_enqueue_style('sssi-frontend');
    }

    /**
     * Enqueue admin assets
     *
     * @param string $hook The current admin page.
     */
    public static function enqueue_admin_assets($hook) {
        if ('toplevel_page_sssi-settings' !== $hook) {
            return;
        }

        wp_enqueue_style('sssi-admin');
        wp_enqueue_script('sssi-admin');

        // Get network icons
        $networks = array('facebook', 'x', 'linkedin', 'pinterest', 'whatsapp', 'bluesky');
        $icons = array();
        foreach ($networks as $network) {
            $icons[$network] = SSSI_Icons::get_network_icon($network);
        }

        // Localize script
        wp_localize_script('sssi-admin', 'SSSI', array(
            'icons' => $icons,
            'defaults' => SSSI_Core::get_default_options(),
            'networks' => SSSI_Icons::get_available_networks(),
            'ajaxurl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('sssi_settings_nonce')
        ));
    }
}

// Initialize assets
add_action('init', array('SSSI_Assets', 'register_assets'));
add_action('wp_enqueue_scripts', array('SSSI_Assets', 'enqueue_frontend_assets'));
add_action('admin_enqueue_scripts', array('SSSI_Assets', 'enqueue_admin_assets')); 