<?php
/**
 * Template for the admin settings page
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) {
    die;
}

$options = $this->get_options();
?>

<div class="wrap">
    <div class="sssi-header">
        <div class="sssi-header-content">
            <div class="sssi-header-text">
                <h1>Super Simple Social Share Icons</h1>
                <p>A lightweight and powerful solution for adding social sharing to your WordPress site.</p>
                <span class="sssi-version">Version <?php echo esc_html(SSSI_VERSION); ?></span>
            </div>
        </div>
    </div>
    
    <div class="sssi-settings-wrap">
        <div class="sssi-settings-main">
            <form method="post" action="options.php" id="sssi-settings-form">
                <?php 
                settings_fields('sssi_options_group');
                wp_nonce_field('sssi_settings_nonce', 'sssi_settings_nonce'); 
                ?>
                
                <div class="sssi-tabs">
                    <button type="button" class="sssi-tab active" data-tab="platforms">
                        <span class="dashicons dashicons-share"></span> Platforms
                    </button>
                    <button type="button" class="sssi-tab" data-tab="appearance">
                        <span class="dashicons dashicons-admin-appearance"></span> Appearance
                    </button>
                    <button type="button" class="sssi-tab" data-tab="position">
                        <span class="dashicons dashicons-layout"></span> Position
                    </button>
                    <button type="button" class="sssi-tab" data-tab="text">
                        <span class="dashicons dashicons-editor-textcolor"></span> Text
                    </button>
                </div>

                <!-- Platforms Tab -->
                <div class="sssi-tab-content active" id="platforms">
                    <div class="sssi-field-group">
                        <h3>Social Networks</h3>
                        <p class="description">Select which social networks to display.</p>
                        
                        <div class="sssi-network-buttons">
                            <?php foreach (SSSI_Icons::get_available_networks() as $network => $label): ?>
                                <button type="button" 
                                        class="sssi-network-button<?php echo in_array($network, $options['networks']) ? ' checked' : ''; ?>"
                                        data-network="<?php echo esc_attr($network); ?>"
                                        style="--network-color: <?php echo esc_attr(SSSI_Icons::get_network_colors()[$network]); ?>">
                                    <span class="sssi-network-icon">
                                        <?php 
                                        echo wp_kses(SSSI_Icons::get_network_icon($network), SSSI_Icons::get_allowed_svg_attributes());
                                        ?>
                                    </span>
                                    <span class="sssi-network-label"><?php echo esc_html($label); ?></span>
                                    <input type="checkbox" 
                                           name="sssi_options[networks][]" 
                                           value="<?php echo esc_attr($network); ?>"
                                           <?php checked(in_array($network, $options['networks'])); ?> 
                                           style="display: none;">
                                </button>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>

                <!-- Appearance Tab -->
                <div class="sssi-tab-content" id="appearance">
                    <div class="sssi-field-group">
                        <h3>Icon Style</h3>
                        <div class="sssi-radio-group">
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[icon_style]" value="brand" 
                                       <?php checked($options['icon_style'], 'brand'); ?>>
                                Brand Colors
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[icon_style]" value="dark" 
                                       <?php checked($options['icon_style'], 'dark'); ?>>
                                Dark Theme
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[icon_style]" value="light" 
                                       <?php checked($options['icon_style'], 'light'); ?>>
                                Light Theme
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[icon_style]" value="custom" 
                                       <?php checked($options['icon_style'], 'custom'); ?>>
                                Custom Colors
                            </label>
                        </div>

                        <div class="sssi-custom-colors<?php echo $options['icon_style'] === 'custom' ? ' active' : ''; ?>">
                            <div class="sssi-color-field">
                                <label for="sssi_custom_bg_color">Background Color</label>
                                <input type="color" 
                                       id="sssi_custom_bg_color"
                                       name="sssi_options[custom_bg_color]" 
                                       value="<?php echo esc_attr($options['custom_bg_color'] ?? '#ffffff'); ?>">
                            </div>
                            <div class="sssi-color-field">
                                <label for="sssi_custom_icon_color">Icon Color</label>
                                <input type="color"
                                       id="sssi_custom_icon_color" 
                                       name="sssi_options[custom_icon_color]" 
                                       value="<?php echo esc_attr($options['custom_icon_color'] ?? '#000000'); ?>">
                            </div>
                            <div class="sssi-color-field">
                                <label for="sssi_custom_border_color">Border Color</label>
                                <input type="color"
                                       id="sssi_custom_border_color" 
                                       name="sssi_options[custom_border_color]" 
                                       value="<?php echo esc_attr($options['custom_border_color'] ?? '#eaeaea'); ?>">
                            </div>
                        </div>
                    </div>

                    <div class="sssi-field-group">
                        <h3>Icon Shape</h3>
                        <div class="sssi-radio-group">
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[icon_shape]" value="rounded" 
                                       <?php checked($options['icon_shape'], 'rounded'); ?>>
                                Rounded
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[icon_shape]" value="square" 
                                       <?php checked($options['icon_shape'], 'square'); ?>>
                                Square
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[icon_shape]" value="circle" 
                                       <?php checked($options['icon_shape'], 'circle'); ?>>
                                Circle
                            </label>
                        </div>
                    </div>

                    <div class="sssi-field-group">
                        <h3>Icon Size & Spacing</h3>
                        <div class="sssi-size-control">
                            <label>Icon Size</label>
                            <input type="range" name="sssi_options[icon_size]" 
                                   min="16" max="48" step="1"
                                   value="<?php echo esc_attr($options['icon_size'] ?? '24'); ?>">
                            <span class="size-value"><?php echo esc_html($options['icon_size'] ?? '24'); ?>px</span>
                        </div>
                        <div class="sssi-size-control">
                            <label>Icon Spacing</label>
                            <input type="range" name="sssi_options[icon_spacing]" 
                                   min="4" max="24" step="1"
                                   value="<?php echo esc_attr($options['icon_spacing'] ?? '8'); ?>">
                            <span class="size-value"><?php echo esc_html($options['icon_spacing'] ?? '8'); ?>px</span>
                        </div>
                    </div>
                </div>

                <!-- Position Tab -->
                <div class="sssi-tab-content" id="position">
                    <div class="sssi-field-group">
                        <h3><?php esc_html_e('Position', 'super-simple-social-share-icons'); ?></h3>
                        <div class="sssi-radio-group">
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[position]" value="before" 
                                       <?php checked($options['position'], 'before'); ?>>
                                <?php esc_html_e('Above Content', 'super-simple-social-share-icons'); ?>
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[position]" value="after" 
                                       <?php checked($options['position'], 'after'); ?>>
                                <?php esc_html_e('Below Content', 'super-simple-social-share-icons'); ?>
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[position]" value="both" 
                                       <?php checked($options['position'], 'both'); ?>>
                                <?php esc_html_e('Above and Below', 'super-simple-social-share-icons'); ?>
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[position]" value="shortcode" 
                                       <?php checked($options['position'], 'shortcode'); ?>>
                                <?php esc_html_e('Use Shortcode', 'super-simple-social-share-icons'); ?>
                            </label>
                        </div>

                        <div class="sssi-shortcode-display" id="shortcodeDisplay">
                            <code>[super_simple_share]</code>
                            <button type="button" class="sssi-copy-button" data-clipboard-text="[super_simple_share]">
                                <span class="dashicons dashicons-clipboard"></span>
                                <?php esc_html_e('Copy', 'super-simple-social-share-icons'); ?>
                            </button>
                        </div>
                    </div>

                    <div class="sssi-field-group">
                        <h3><?php esc_html_e('Alignment', 'super-simple-social-share-icons'); ?></h3>
                        <div class="sssi-radio-group">
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[alignment]" value="left" 
                                       <?php checked($options['alignment'], 'left'); ?>>
                                <?php esc_html_e('Left', 'super-simple-social-share-icons'); ?>
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[alignment]" value="center" 
                                       <?php checked($options['alignment'], 'center'); ?>>
                                <?php esc_html_e('Center', 'super-simple-social-share-icons'); ?>
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[alignment]" value="right" 
                                       <?php checked($options['alignment'], 'right'); ?>>
                                <?php esc_html_e('Right', 'super-simple-social-share-icons'); ?>
                            </label>
                        </div>
                    </div>
                </div>

                <!-- Text Tab -->
                <div class="sssi-tab-content" id="text">
                    <div class="sssi-field-group">
                        <h3>Share Text</h3>
                        <input type="text" name="sssi_options[share_text]" 
                               value="<?php echo esc_attr($options['share_text']); ?>" 
                               class="regular-text">
                        <p class="description">The text displayed with your share buttons.</p>
                    </div>

                    <div class="sssi-field-group">
                        <h3>Text Position</h3>
                        <div class="sssi-radio-group">
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_position]" value="above" 
                                       <?php checked($options['text_position'], 'above'); ?>>
                                Above Icons
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_position]" value="left" 
                                       <?php checked($options['text_position'], 'left'); ?>>
                                Left of Icons
                            </label>
                        </div>
                    </div>

                    <div class="sssi-field-group">
                        <h3><?php esc_html_e('Text Style', 'super-simple-social-share-icons'); ?></h3>
                        <div class="sssi-radio-group">
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_style]" value="normal" 
                                       <?php checked($options['text_style'], 'normal'); ?>>
                                <?php esc_html_e('Normal', 'super-simple-social-share-icons'); ?>
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_style]" value="underline" 
                                       <?php checked($options['text_style'], 'underline'); ?>>
                                <?php esc_html_e('Underlined', 'super-simple-social-share-icons'); ?>
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_style]" value="uppercase" 
                                       <?php checked($options['text_style'], 'uppercase'); ?>>
                                <?php esc_html_e('Uppercase', 'super-simple-social-share-icons'); ?>
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_style]" value="italic" 
                                       <?php checked($options['text_style'], 'italic'); ?>>
                                <?php esc_html_e('Italic', 'super-simple-social-share-icons'); ?>
                            </label>
                        </div>
                    </div>

                    <div class="sssi-field-group">
                        <h3>Text Weight</h3>
                        <div class="sssi-radio-group">
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_weight]" value="normal" 
                                       <?php checked($options['text_weight'] ?? 'semibold', 'normal'); ?>>
                                Normal (400)
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_weight]" value="medium" 
                                       <?php checked($options['text_weight'] ?? 'semibold', 'medium'); ?>>
                                Medium (500)
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_weight]" value="semibold" 
                                       <?php checked($options['text_weight'] ?? 'semibold', 'semibold'); ?>>
                                Semi Bold (600)
                            </label>
                            <label class="sssi-radio-label">
                                <input type="radio" name="sssi_options[text_weight]" value="bold" 
                                       <?php checked($options['text_weight'] ?? 'semibold', 'bold'); ?>>
                                Bold (700)
                            </label>
                        </div>
                    </div>

                    <div class="sssi-field-group">
                        <h3>Text Size</h3>
                        <div class="sssi-size-control">
                            <label>Size</label>
                            <input type="range" name="sssi_options[text_size]" 
                                   min="12" max="24" step="1"
                                   value="<?php echo esc_attr($options['text_size'] ?? '18'); ?>">
                            <span class="size-value"><?php echo esc_html($options['text_size'] ?? '18'); ?>px</span>
                        </div>
                    </div>
                </div>
            </form>
        </div>

        <div class="sssi-settings-sidebar">
            <div class="sssi-preview-container">
                <div class="sssi-preview-header">
                    <h3>Preview</h3>
                </div>
                <div class="sssi-preview-content">
                    <!-- Preview content will be dynamically updated via JS -->
                </div>
            </div>

            <button type="submit" form="sssi-settings-form" class="button button-primary sssi-save-button">
                Save Changes
            </button>

            <div class="sssi-support-section">
                <div class="sssi-support-header">
                    <h3>Documentation & Support</h3>
                </div>
                <div class="sssi-support-links">
                    <a href="https://voltblocks.com/documentation/" target="_blank" class="sssi-support-link">
                        <span class="dashicons dashicons-book"></span>
                        <?php esc_html_e('Documentation', 'super-simple-social-share-icons'); ?>
                    </a>
                    <a href="https://voltblocks.com/contact/" target="_blank" class="sssi-support-link">
                        <span class="dashicons dashicons-admin-users"></span>
                        <?php esc_html_e('Get Support', 'super-simple-social-share-icons'); ?>
                    </a>
                    <a href="https://www.buymeacoffee.com/voltblocks" target="_blank" class="sssi-support-link">
                        <span class="dashicons dashicons-heart"></span>
                        <?php esc_html_e('Support Development', 'super-simple-social-share-icons'); ?>
                    </a>
                </div>
            </div>
        </div>
    </div>
</div> 